package logwire.core.bo.object;

import logwire.core.bo.annotation.Column;
import logwire.core.bo.annotation.Composite;
import logwire.core.bo.field.BizExpando;
import logwire.core.bo.field.BizOne;

import java.time.OffsetDateTime;
import java.util.Map;

/**
 * BO 生成的Model,audit=false version=true domain=true, 指定ID为主键，非AUTO；audit由BO控制
 * BO 子表字段(多对多、数组、大文本)生成的Model，audit/version/domain都为false
 */
public abstract class BizObject extends ModelObject {
    /**
     * 事务类型 insert/update/delete
     */
    String txCode;

    /**
     * 当事务类型为update时，记录修改过的字段
     */
    Map<String, Object> updatedFields;

    Long id;// BO 的ID全部为雪花ID

    int version;

    @Column(label = "BO名称")
    String boName;

    BizOne<User> insertUser;

    OffsetDateTime insertDate;

    BizOne<User> updateUser;

    OffsetDateTime updateDate;

    @Composite(label = "项目扩展字段", prefix = "exp_")
    BizExpando exps;

    String domainName;


    @Override
    public Object getId() {
        return id;
    }


    public String getTxCode() {
        return txCode;
    }

    public void setTxCode(String txCode) {
        this.txCode = txCode;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public int getVersion() {
        return version;
    }

    public void setVersion(int version) {
        this.version = version;
    }

    public String getBoName() {
        return boName;
    }

    public void setBoName(String boName) {
        this.boName = boName;
    }

    public Map<String, Object> getUpdatedFields() {
        return updatedFields;
    }

    public BizOne<User> getInsertUser() {
        return insertUser;
    }

    public void setInsertUser(BizOne<User> insertUser) {
        this.insertUser = insertUser;
    }

    public OffsetDateTime getInsertDate() {
        return insertDate;
    }

    public void setInsertDate(OffsetDateTime insertDate) {
        this.insertDate = insertDate;
    }

    public OffsetDateTime getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(OffsetDateTime updateDate) {
        this.updateDate = updateDate;
    }

    public BizOne<User> getUpdateUser() {
        return updateUser;
    }

    public void setUpdateUser(BizOne<User> updateUser) {
        this.updateUser = updateUser;
    }

    public BizExpando getExps() {
        return exps;
    }

    public void setExps(BizExpando exps) {
        this.exps = exps;
    }

    public String getDomainName() {
        return domainName;
    }

    public void setDomainName(String domainName) {
        this.domainName = domainName;
    }
}
